@@ -4,7 +4,7 @@
  * --------
  * Author: Jos Jorge Enrquez (jenriquez@users.sourceforge.net)
  * Copyright: (c) 2005 Jos Jorge Enrquez Rodrguez (http://www.zonamakers.com)
- * Release Version: 1.0.7.19
+ * Release Version: 1.0.7.22
  * Date Started: 2005/06/21
  *
  * GML language file for GeSHi.
@@ -73,7 +73,7 @@ $language_data = array (
 		1 => array(
 			'break', 'continue', 'do', 'until', 'if', 'else',
 			'exit', 'for', 'for', 'repeat', 'return', 'switch',
-			'case', 'default', 'var', 'while', 'with', 'div', 'mod', 
+			'case', 'default', 'var', 'while', 'with', 'div', 'mod',
 			// GML Language overview
 			'self', 'other', 'all', 'noone', 'global',
 			),
@@ -450,7 +450,7 @@ $language_data = array (
 			1 => 'font-weight: bold; color: #000000;',
 			2 => 'font-weight: bold; color: #000000;',
 			3 => 'color: navy;',
-			4 => 'color: brown',
+			4 => 'color: #663300;',
 			),
 		'COMMENTS' => array(
 			1 => 'font-style: italic; color: green;',
