@@ -4,13 +4,15 @@
  * ----------
  * Author: Flaie (fireflaie@gmail.com)
  * Copyright: (c) 2005 Flaie, Nigel McNie (http://qbnz.com/highlighter)
- * Release Version: 1.0.7.20
+ * Release Version: 1.0.7.22
  * Date Started: 2005/08/27
  *
  * OCaml (Objective Caml) language file for GeSHi.
  *
  * CHANGES
  * -------
+ * 2008/03/29 (1.0.7.22)
+ *   -  Fixed warnings resulting from missing style information
  * 2005/08/27 (1.0.0)
  *   -  First Release
  *
@@ -47,7 +49,7 @@ $language_data = array (
 	'KEYWORDS' => array(
 	   /* main OCaml keywords */
 		1 => array(
-			'and', 'As', 'asr', 'begin', 'Class', 'Closed', 'constraint', 'do', 'done', 'downto', 'else',
+			'and', 'as', 'asr', 'begin', 'class', 'closed', 'constraint', 'do', 'done', 'downto', 'else',
 			'end', 'exception', 'external', 'failwith', 'false', 'flush', 'for', 'fun', 'function', 'functor',
 			'if', 'in', 'include', 'inherit',  'incr', 'land', 'let', 'load', 'los', 'lsl', 'lsr', 'lxor',
 			'match', 'method', 'mod', 'module', 'mutable', 'new', 'not', 'of', 'open', 'option', 'or', 'parser',
@@ -66,12 +68,12 @@ $language_data = array (
 		   ),
 		/* just link to the Pervasives functions library, cause it's the default opened library when starting OCaml */
 		3 => array(
-			'raise', 'invalid_arg', 'failwith', 'compare', 'min', 'max', 'succ', 'pred', 'mod', 'abs', 
-			'max_int', 'min_int', 'sqrt', 'exp', 'log', 'log10', 'cos', 'sin', 'tan', 'acos', 'asin', 
+			'raise', 'invalid_arg', 'failwith', 'compare', 'min', 'max', 'succ', 'pred', 'mod', 'abs',
+			'max_int', 'min_int', 'sqrt', 'exp', 'log', 'log10', 'cos', 'sin', 'tan', 'acos', 'asin',
 			'atan', 'atan2', 'cosh', 'sinh', 'tanh', 'ceil', 'floor', 'abs_float', 'mod_float', 'frexp',
 			'ldexp', 'modf', 'float', 'float_of_int', 'truncate', 'int_of_float', 'infinity', 'nan',
-			'max_float', 'min_float', 'epsilon_float', 'classify_float', 'int_of_char', 'char_of_int', 
-			'ignore', 'string_of_bool', 'bool_of_string', 'string_of_int', 'int_of_string', 
+			'max_float', 'min_float', 'epsilon_float', 'classify_float', 'int_of_char', 'char_of_int',
+			'ignore', 'string_of_bool', 'bool_of_string', 'string_of_int', 'int_of_string',
 			'string_of_float', 'float_of_string', 'fst', 'snd', 'stdin', 'stdout', 'stderr', 'print_char',
 			'print_string', 'print_int', 'print_float', 'print_endline', 'print_newline', 'prerr_char',
 			'prerr_string', 'prerr_int', 'prerr_float', 'prerr_endline', 'prerr_newline', 'read_line',
@@ -81,7 +83,7 @@ $language_data = array (
 			'open_in', 'open_in_bin', 'open_in_gen', 'input_char', 'input_line', 'input', 'really_input',
 			'input_byte', 'input_binary_int', 'input_value', 'seek_in', 'pos_in', 'in_channel_length',
 			'close_in', 'close_in_noerr', 'set_binary_mode_in', 'incr', 'decr', 'string_of_format',
-			'format_of_string', 'exit', 'at_exit' 
+			'format_of_string', 'exit', 'at_exit'
 		   ),
 		/* here Pervasives Types */
 		4 => array (
@@ -94,20 +96,24 @@ $language_data = array (
 		),
 	/* highlighting symbols is really important in OCaml */
 	'SYMBOLS' => array(
-			';', '!', ':', '.', '=', '%', '^', '*', '-', '/', '+', 
+			';', '!', ':', '.', '=', '%', '^', '*', '-', '/', '+',
 			'>', '<', '(', ')', '[', ']', '&', '|', '#', "'"
-			), 
+			),
 	'CASE_SENSITIVE' => array(
 		GESHI_COMMENTS => true,
 		1 => false,
-		2 => true, /* functions name are case seinsitive */
+		2 => true, /* functions name are case sensitive */
 		3 => true, /* types name too */
 		4 => true  /* finally exceptions too */
 		),
 	'STYLES' => array(
 		'KEYWORDS' => array(
-			1 => 'color: #06c; font-weight: bold;' /* nice blue */
-			),
+			1 => 'color: #06c; font-weight: bold;', /* nice blue */
+			2 => 'color: #06c; font-weight: bold;', /* nice blue */
+			3 => 'color: #06c; font-weight: bold;', /* nice blue */
+			4 => 'color: #06c; font-weight: bold;', /* nice blue */
+			5 => 'color: #06c; font-weight: bold;' /* nice blue */
+            ),
 		'COMMENTS' => array(
 			'MULTI' => 'color: #5d478b; font-style: italic;' /* light purple */
 			),
@@ -127,7 +133,7 @@ $language_data = array (
 			),
 		'REGEXPS' => array(
 			),
-		'SYMBOLS' => array( 
+		'SYMBOLS' => array(
 			0 => 'color: #a52a2a;' /* maroon */
 			),
 		'SCRIPT' => array(
@@ -137,9 +143,9 @@ $language_data = array (
 	   /* some of keywords are Pervasives functions (land, lxor, asr, ...) */
 		1 => '',
 		/* link to the wanted library */
-		2 => 'http://caml.inria.fr/pub/docs/manual-ocaml/libref/{FNAME}.html', 
+		2 => 'http://caml.inria.fr/pub/docs/manual-ocaml/libref/{FNAME}.html',
 		/* link to Pervasives functions */
-		3 => 'http://caml.inria.fr/pub/docs/manual-ocaml/libref/Pervasives.html#VAL{FNAME}', 
+		3 => 'http://caml.inria.fr/pub/docs/manual-ocaml/libref/Pervasives.html#VAL{FNAME}',
 		/* link to Pervasives type */
 		4 => 'http://caml.inria.fr/pub/docs/manual-ocaml/libref/Pervasives.html#TYPE{FNAME}',
 		/* link to Pervasives exceptions */
