@@ -4,13 +4,15 @@
  * ---------
  * Author: Roberto Rossi (rsoftware@altervista.org)
  * Copyright: (c) 2004 Roberto Rossi (http://rsoftware.altervista.org), Nigel McNie (http://qbnz.com/highlighter)
- * Release Version: 1.0.7.19
+ * Release Version: 1.0.7.22
  * Date Started: 2004/08/30
  *
  * OpenOffice.org Basic language file for GeSHi.
  *
  * CHANGES
  * -------
+ * 2008/05/23 (1.0.7.22)
+ *  -  Added description of extra language features (SF#1970248)
  * 2004/11/27 (1.0.1)
  *  -  Added support for multiple object splitters
  * 2004/10/27 (1.0.0)
@@ -43,13 +45,14 @@ $language_data = array (
 	'LANG_NAME' => 'OpenOffice.org Basic',
 	'COMMENT_SINGLE' => array(1 => "'"),
 	'COMMENT_MULTI' => array(),
+	//Single-Line comments using REM keyword
+	'COMMENT_REGEXP' => array(2 => '/\bREM.*?$/i'),
 	'CASE_KEYWORDS' => GESHI_CAPS_NO_CHANGE,
 	'QUOTEMARKS' => array('"'),
 	'ESCAPE_CHAR' => '',
 	'KEYWORDS' => array(
 		1 => array(
-			'dim','private','public','global','as','if','redim','true','set',
-			'byval',
+			'dim','private','public','global','as','if','redim','true','set','byval',
 			'false','bool','double','integer','long','object','single','variant',
 			'msgbox','print','inputbox','green','blue','red','qbcolor',
 			'rgb','open','close','reset','freefile','get','input','line',
@@ -59,9 +62,9 @@ $language_data = array (
 			'dateserial','datevalue','day','month','weekday','year','cdatetoiso',
 			'cdatefromiso','hour','minute','second','timeserial','timevalue',
 			'date','now','time','timer','erl','err','error','on','error','goto','resume',
-			'and','eqv','imp','not','or','xor','mod','','atn','cos','sin','tan','log',
+			'and','eqv','imp','not','or','xor','mod','atn','cos','sin','tan','log',
 			'exp','rnd','randomize','sqr','fix','int','abs','sgn','hex','oct',
-			'it','then','else','select','case','iif','do','loop','for','next',
+			'it','then','else','select','case','iif','do','loop','for','next','to',
 			'while','wend','gosub','return','goto','on','goto','call','choose','declare',
 			'end','exit','freelibrary','function','rem','stop','sub','switch','with',
 			'cbool','cdate','cdbl','cint','clng','const','csng','cstr','defbool',
@@ -87,7 +90,8 @@ $language_data = array (
 			1 => 'color: #b1b100;'
 			),
 		'COMMENTS' => array(
-			1 => 'color: #808080;'
+			1 => 'color: #808080;',
+			2 => 'color: #808080;'
 			),
 		'BRACKETS' => array(
 			0 => 'color: #66cc66;'
